# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17proto/transaction.proto\x12\x0btransaction\"\xdb\x03\n\x0bTransaction\x12\x10\n\x08\x62id_uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x62id_created_at\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x0f\n\x07\x62id_krw\x18\x04 \x01(\x02\x12\x0f\n\x07\x62id_fee\x18\x05 \x01(\x02\x12\x12\n\nbid_failed\x18\x06 \x01(\x05\x12\x12\n\nask_failed\x18\x07 \x01(\x05\x12\x14\n\x0corder_status\x18\x08 \x01(\x05\x12\x15\n\rtether_volume\x18\t \x01(\x02\x12\x1a\n\rbid_filled_at\x18\n \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x61sk_uuid\x18\x0b \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0e\x61sk_created_at\x18\x0c \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rask_filled_at\x18\r \x01(\tH\x03\x88\x01\x01\x12\x16\n\task_price\x18\x0e \x01(\x02H\x04\x88\x01\x01\x12\x14\n\x07\x61sk_fee\x18\x0f \x01(\tH\x05\x88\x01\x01\x12\x14\n\x07revenue\x18\x10 \x01(\tH\x06\x88\x01\x01\x42\x10\n\x0e_bid_filled_atB\x0b\n\t_ask_uuidB\x11\n\x0f_ask_created_atB\x10\n\x0e_ask_filled_atB\x0c\n\n_ask_priceB\n\n\x08_ask_feeB\n\n\x08_revenue\"7\n\x12TransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62ot_name\x18\x02 \x01(\t\"I\n\x1a\x43urrentTransactionResponse\x12+\n\tpositions\x18\x01 \x03(\x0b\x32\x18.transaction.Transaction\"O\n\x16PositionHistoryRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\"D\n\x17PositionHistoryResponse\x12)\n\x07history\x18\x01 \x03(\x0b\x32\x18.transaction.Transaction\"8\n\x10\x44\x42\x43ommitResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"^\n\x0f\x42idPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x15\n\rtether_volume\x18\x04 \x01(\x02\"3\n\x0e\x42idFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\"Y\n\x0f\x41skPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x03 \x01(\t\x12\x11\n\task_price\x18\x04 \x01(\x02\"D\n\x0e\x41skFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x02 \x01(\t\x12\x0f\n\x07\x61sk_fee\x18\x03 \x01(\t\",\n\x0bUuidRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t2\xac\x05\n\x12TransactionService\x12\x62\n\x16GetCurrentTransactions\x12\x1f.transaction.TransactionRequest\x1a\'.transaction.CurrentTransactionResponse\x12`\n\x13GetPastTransactions\x12#.transaction.PositionHistoryRequest\x1a$.transaction.PositionHistoryResponse\x12H\n\tBidPlaced\x12\x1c.transaction.BidPlaceRequest\x1a\x1d.transaction.DBCommitResponse\x12G\n\tBidFilled\x12\x1b.transaction.BidFillRequest\x1a\x1d.transaction.DBCommitResponse\x12H\n\tAskPlaced\x12\x1c.transaction.AskPlaceRequest\x1a\x1d.transaction.DBCommitResponse\x12G\n\tAskFilled\x12\x1b.transaction.AskFillRequest\x1a\x1d.transaction.DBCommitResponse\x12T\n\x19OrderFailedAfterBidPlaced\x12\x18.transaction.UuidRequest\x1a\x1d.transaction.DBCommitResponse\x12T\n\x19OrderFailedAfterAskPlaced\x12\x18.transaction.UuidRequest\x1a\x1d.transaction.DBCommitResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRANSACTION']._serialized_start=41
  _globals['_TRANSACTION']._serialized_end=516
  _globals['_TRANSACTIONREQUEST']._serialized_start=518
  _globals['_TRANSACTIONREQUEST']._serialized_end=573
  _globals['_CURRENTTRANSACTIONRESPONSE']._serialized_start=575
  _globals['_CURRENTTRANSACTIONRESPONSE']._serialized_end=648
  _globals['_POSITIONHISTORYREQUEST']._serialized_start=650
  _globals['_POSITIONHISTORYREQUEST']._serialized_end=729
  _globals['_POSITIONHISTORYRESPONSE']._serialized_start=731
  _globals['_POSITIONHISTORYRESPONSE']._serialized_end=799
  _globals['_DBCOMMITRESPONSE']._serialized_start=801
  _globals['_DBCOMMITRESPONSE']._serialized_end=857
  _globals['_BIDPLACEREQUEST']._serialized_start=859
  _globals['_BIDPLACEREQUEST']._serialized_end=953
  _globals['_BIDFILLREQUEST']._serialized_start=955
  _globals['_BIDFILLREQUEST']._serialized_end=1006
  _globals['_ASKPLACEREQUEST']._serialized_start=1008
  _globals['_ASKPLACEREQUEST']._serialized_end=1097
  _globals['_ASKFILLREQUEST']._serialized_start=1099
  _globals['_ASKFILLREQUEST']._serialized_end=1167
  _globals['_UUIDREQUEST']._serialized_start=1169
  _globals['_UUIDREQUEST']._serialized_end=1213
  _globals['_TRANSACTIONSERVICE']._serialized_start=1216
  _globals['_TRANSACTIONSERVICE']._serialized_end=1900
# @@protoc_insertion_point(module_scope)
