# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/tetherbot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto/tetherbot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15proto/tetherbot.proto\x12\x03\x62ot\"\x9c\x01\n\x08Position\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x16\n\x0e\x62id_order_uuid\x18\x02 \x01(\t\x12\x13\n\x0b\x65ntry_price\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\x16\n\x0e\x61sk_order_uuid\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0ctarget_price\x18\x07 \x01(\x02\"\x1d\n\nKeyRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\"3\n\x0bKeyResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"6\n\x16\x42\x61tchPositionsResponse\x12\x1c\n\x05\x62\x61tch\x18\x01 \x03(\x0b\x32\r.bot.Position\"]\n\x11PositionsResponse\x12\x14\n\x0cposition_idx\x18\x01 \x01(\x05\x12\x1f\n\x08position\x18\x02 \x01(\x0b\x32\r.bot.Position\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"<\n\x12MarketDataResponse\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x17\n\x0ftimestamp_epoch\x18\x02 \x01(\x03\x32\xb5\x02\n\x10TetherBotService\x12\x43\n\x13GetCurrentPositions\x12\x0f.bot.KeyRequest\x1a\x1b.bot.BatchPositionsResponse\x12\x44\n\x17StreamRealTimePositions\x12\x0f.bot.KeyRequest\x1a\x16.bot.PositionsResponse0\x01\x12?\n\x11StreamMarketValue\x12\x0f.bot.KeyRequest\x1a\x17.bot.MarketDataResponse0\x01\x12*\n\x05Start\x12\x0f.bot.KeyRequest\x1a\x10.bot.KeyResponse\x12)\n\x04Stop\x12\x0f.bot.KeyRequest\x1a\x10.bot.KeyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.tetherbot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSITION']._serialized_start=31
  _globals['_POSITION']._serialized_end=187
  _globals['_KEYREQUEST']._serialized_start=189
  _globals['_KEYREQUEST']._serialized_end=218
  _globals['_KEYRESPONSE']._serialized_start=220
  _globals['_KEYRESPONSE']._serialized_end=271
  _globals['_BATCHPOSITIONSRESPONSE']._serialized_start=273
  _globals['_BATCHPOSITIONSRESPONSE']._serialized_end=327
  _globals['_POSITIONSRESPONSE']._serialized_start=329
  _globals['_POSITIONSRESPONSE']._serialized_end=422
  _globals['_MARKETDATARESPONSE']._serialized_start=424
  _globals['_MARKETDATARESPONSE']._serialized_end=484
  _globals['_TETHERBOTSERVICE']._serialized_start=487
  _globals['_TETHERBOTSERVICE']._serialized_end=796
# @@protoc_insertion_point(module_scope)
